@@ -46,3 +46,11 @@ def generate( **kwargs ):
 
     return Nanoid( **kwargs ).nanoid
 
+def run( *sys_args ):
+
+    id = generate()
+    print (id)
+
+if __name__ == '__main__':
+    
+    run()
